QuDataInput - Qudas 0.1.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# QuDataInput

量子デバイスへの入力データを変換するクラスです。

class qudas.qudata.QuDataInput(prob: dict | None = None)

  Bases: `QuDataBase`

  量子データ

  __abstractmethods__ = frozenset({})
  __add__(other)
  __init__(prob: dict | None = None) → None

    初期データとして最適化問題を受け取るクラス。

    Parameters:

      prob (dict, optional) – 最適化問題データ。デフォルトはNone。

  __module__ = 'qudas.qudata.qudata_input'
  __mul__(other)
  __pow__(other: int)
  __sub__(other)
  from_amplify(prob: Poly)

    amplifyデータを読み込む

    Parameters:

      prob (Poly) – 組み合わせ最適化問題

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_array(prob: ndarray)

    numpyデータを読み込む

    Parameters:

      prob (np.ndarray) – 組み合わせ最適化問題

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_csv(path: str, encoding='utf-8-sig')

    csvデータを読み込む

    Parameters:

      path (str) – ファイルパス文字列

    Raises:

      Exception – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_dimod_bqm(prob: BinaryQuadraticModel)

    dimodのbqmデータを読み込む

    Parameters:

      prob (dimod.BinaryQuadraticModel) – dimodのbqmデータ

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_json(path: str)

    jsonデータを読み込む

    Parameters:

      path (str) – ファイルパス文字列

    Raises:

      Exception – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_networkx(prob: Graph)

    グラフデータを読み込む

    Parameters:

      prob (nx.Graph) – networkxのグラフデータ

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_pandas(prob: DataFrame)

    pandasデータを読み込む

    Parameters:

      prob (pd.DataFrame) – pandasのデータフレーム

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_pulp(prob: LpProblem)

    pulpデータを読み込む

    Parameters:

      prob (LpProblem) – 線形計画問題

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_pyqubo(prob: Base)

    pyquboデータを読み込む

    Parameters:

      prob (Base) – 組み合わせ最適化問題

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  from_sympy(prob: Expr)

    sympyデータを読み込む

    Parameters:

      prob (sympy.core.expr.Expr) – sympyデータ

    Raises:

      TypeError – 形式エラー

    Returns:

      量子データ

    Return type:

      Qudata

  to_amplify() → Poly

    amplify形式に変換

    Returns:

      組み合わせ最適化問題

    Return type:

      Poly

  to_array() → ndarray

    numpy形式に変換

    Raises:

      ValueError – 次元エラー

    Returns:

      QUBO行列

    Return type:

      np.ndarray

  to_csv(name='qudata') → None

    データをCSV形式で保存

    Parameters:

      name (str, optional) – ファイル名. Defaults to “qudata”.

    Raises:

      ValueError – 書き出しエラー

  to_dimod_bqm() → BinaryQuadraticModel

    dimodのbqm形式に変換

    Returns:

      dimodのbqmデータ

    Return type:

      dimod.BinaryQuadraticModel

  to_json(name='qudata') → None

    json形式に変換

    Parameters:

      name (str, optional) – ファイル名. Defaults to “qudata”.

    Raises:

      ValueError – 書き出しエラー

  to_networkx() → Graph

    networkx形式に変換

    Raises:

      ValueError – 次元エラー

    Returns:

      networkxのグラフデータ

    Return type:

      nx.Graph

  to_pandas() → DataFrame

    pandas形式に変換

    Returns:

      pandasデータ

    Return type:

      pd.DataFrame

  to_pulp() → LpProblem

    pulp形式に変換

    Raises:

      ValueError – 変数エラー

    Returns:

      線形計画問題

    Return type:

      LpProblem

  to_pyqubo() → Base

    pyqubo形式に変換

    Returns:

      組み合わせ最適化問題

    Return type:

      Base

  to_sympy() → Expr

    sympy形式に変換

    Returns:

      sympyの多項式データ

    Return type:

      sympy.core.expr.Expr